@@ -33,6 +33,7 @@ import Codec.Encryption.OpenPGP.Types
 import Control.Applicative ((<|>), optional)
 import Control.Arrow ((&&&))
 import Control.Lens ((^.), (^..), _1, _2)
+import Control.Monad.Trans.Except (except, runExcept)
 import Control.Monad.Trans.Resource (MonadResource, MonadThrow)
 import qualified Data.Aeson as A
 import Data.Binary (get, put)
@@ -105,7 +106,6 @@ import Options.Applicative.Builder
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
-import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
 import Prettyprinter.Render.Text (hPutDoc, putDoc)
 import Prettyprinter ((<+>), fillSep, hardline, list, pretty)
 import System.IO (BufferMode(..), Handle, hFlush, hSetBuffering, stderr)
@@ -123,11 +123,11 @@ grabMatchingKeysConduit fp filt srch =
      else CL.filter matchAny)
   where
     matchAny tk =
-      either (const False) id $ fmap (keyMatchesFingerprint True tk) efp <|>
+      either (const False) id $ runExcept $ fmap (keyMatchesFingerprint True tk) efp <|>
       fmap (keyMatchesEightOctetKeyId True tk . Right) eeok <|>
       return (keyMatchesUIDSubString srch tk)
-    efp = parseFingerprint srch
-    eeok = parseEightOctetKeyId srch
+    efp = (except . parseFingerprint) srch
+    eeok = (except . parseEightOctetKeyId) srch
     ufp = RTKFilterPredicate (parseE srch)
     parseE =
       either (error . ("filter parse error: " ++)) id . parseTKExp . T.unpack -- this should be more specialized
@@ -242,7 +242,7 @@ listO homedir =
   pure ""
   where
     targetHelp =
-      helpDoc . Just . toAnsiWlPprint $ pretty "target (which keys to output)*"
+      helpDoc . Just $ pretty "target (which keys to output)*"
 
 graphO :: String -> Parser Options
 graphO homedir =
@@ -260,11 +260,11 @@ graphO homedir =
   pure ""
   where
     ofhelp =
-      helpDoc . Just . toAnsiWlPprint $ pretty "output format" <> hardline <>
+      helpDoc . Just $ pretty "output format" <> hardline <>
       list (map (pretty . show) ofchoices)
     ofchoices = [minBound .. maxBound] :: [GraphOutputFormat]
     targetHelp =
-      helpDoc . Just . toAnsiWlPprint $ pretty "target (which keys to graph)*"
+      helpDoc . Just $ pretty "target (which keys to graph)*"
 
 findPathsO :: String -> Parser Options
 findPathsO homedir =
@@ -283,13 +283,13 @@ findPathsO homedir =
   argument str (metavar "TO-KEYS" <> toHelp)
   where
     targetHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "target (which keys to use in pathfinding)*"
     fromHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "from (which keys to use for the source of paths)*"
     toHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "to (which keys to use for the destinations of paths)*"
 
 dispatch :: Command -> IO ()
@@ -307,9 +307,9 @@ main = do
     (prefs showHelpOnError)
     (info
        (helper <*> versioner "hkt" <*> cmd homedir)
-       (headerDoc (Just (toAnsiWlPprint (banner "hkt"))) <>
+       (headerDoc (Just (banner "hkt")) <>
         progDesc "hOpenPGP Keyring Tool" <>
-        footerDoc (Just (toAnsiWlPprint (warranty "hkt"))))) >>=
+        footerDoc (Just (warranty "hkt")))) >>=
     dispatch
 
 cmd :: String -> Parser Command
@@ -337,7 +337,7 @@ cmd homedir =
           (progDesc "list matching keys" <> footerDoc (Just foot))))
   where
     foot =
-      toAnsiWlPprint $ hardline <>
+      hardline <>
       fillSep
         [ pretty "*if --filter is not specified, this must be"
         , pretty "a fingerprint,"
@@ -521,11 +521,11 @@ doFindPaths o = do
   where
     filt = targetIsFilter o
     matchAny srch tk =
-      either (const False) id $
-      fmap (keyMatchesFingerprint True tk) (parseFingerprint srch) <|>
+      either (const False) id $ runExcept $
+      fmap (keyMatchesFingerprint True tk) ((except . parseFingerprint) srch) <|>
       fmap
         (keyMatchesEightOctetKeyId True tk . Right)
-        (parseEightOctetKeyId srch) <|>
+        ((except . parseEightOctetKeyId) srch) <|>
       return (keyMatchesUIDSubString srch tk)
     ufpt srch = RTKFilterPredicate (parseE srch)
     parseE e =
