@@ -1,5 +1,5 @@
 -- hop.hs: hOpenPGP-stateless OpenPGP (sop) tool
--- Copyright © 2019-2022  Clint Adams
+-- Copyright © 2019-2023  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -33,12 +33,10 @@ import Codec.Encryption.OpenPGP.Signatures
   )
 import Codec.Encryption.OpenPGP.Types
 import Control.Applicative ((<|>), optional, some)
-import Control.Arrow ((&&&))
 import Control.Error.Util (note)
-import Control.Lens ((^.), (^..), _1, _2)
 import Control.Monad ((>=>), forM_)
-import Control.Monad.IO.Class (MonadIO, liftIO)
-import Control.Monad.State.Lazy (MonadState, StateT, evalStateT, get, modify)
+import Control.Monad.IO.Class (liftIO)
+import Control.Monad.State.Lazy (StateT, evalStateT, get, modify)
 import Control.Monad.Trans.Resource (MonadResource, MonadThrow)
 import qualified Crypto.PubKey.RSA as RSA
 import qualified Data.Aeson as A
@@ -48,7 +46,7 @@ import Data.Binary.Put (runPut)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
 import qualified Data.ByteString.Lazy.Char8 as BLC8
-import Data.Conduit (ConduitM, (.|), runConduitRes)
+import Data.Conduit ((.|), runConduitRes)
 import qualified Data.Conduit.Binary as CB
 import qualified Data.Conduit.Combinators as CC
 import qualified Data.Conduit.List as CL
@@ -59,16 +57,14 @@ import Data.Conduit.OpenPGP.Keyring
   )
 import Data.Conduit.OpenPGP.Verify (conduitVerify)
 import Data.Conduit.Serialization.Binary (conduitGet)
-import Data.Data.Lens (biplate)
 import Data.Either (fromRight, isRight, rights)
 import Data.List (find)
-import Data.Maybe (catMaybes, fromJust, fromMaybe, listToMaybe, mapMaybe)
+import Data.Maybe (catMaybes, fromJust, listToMaybe)
 import Data.Monoid ((<>))
 import qualified Data.Set as S
 import Data.Text (Text)
 import qualified Data.Text as T
 import qualified Data.Text.Encoding as TE
-import qualified Data.Text.Lazy as TL
 import Data.Time.Clock.POSIX (POSIXTime, getPOSIXTime, posixSecondsToUTCTime)
 import qualified Data.Vector as V
 import Data.Version (showVersion)
@@ -115,7 +111,6 @@ import Options.Applicative.Builder
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
-import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
 import Prettyprinter
   ( (<+>)
   , fillSep
@@ -124,7 +119,7 @@ import Prettyprinter
   , pretty
   , softline
   )
-import Prettyprinter.Render.Text (hPutDoc, putDoc)
+import Prettyprinter.Render.Text (hPutDoc)
 import System.IO (BufferMode(..), Handle, hFlush, hSetBuffering, stderr, stdin)
 
 data Command
@@ -172,10 +167,10 @@ o =
   argument str (metavar "BLOB" <> blobHelp)
   where
     sigHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "file containing OpenPGP binary signatures"
     blobHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "file containing binary blob to be validated"
 
 dispatch :: POSIXTime -> Command -> IO ()
@@ -196,9 +191,9 @@ main = do
     (prefs showHelpOnError)
     (info
        (helper <*> versioner "hop" <*> cmd)
-       (headerDoc (Just (toAnsiWlPprint (banner "hop"))) <>
+       (headerDoc (Just (banner "hop")) <>
         progDesc "hOpenPGP Validator Tool" <>
-        footerDoc (Just (toAnsiWlPprint (warranty "hop"))))) >>=
+        footerDoc (Just (warranty "hop")))) >>=
     dispatch cpt
 
 banner' :: Handle -> IO ()
@@ -296,7 +291,7 @@ aoP =
      help "do the sane thing and unconditionally armor the output")
   where
     armortypeHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "ASCII armor type" <>
       softline <> list (map (pretty . fst) armorTypes)
 
@@ -485,7 +480,7 @@ soP =
         help "paths to at least one secret key, one key per filename"))
   where
     astypeHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "what to treat the input as" <>
       softline <> list (map (pretty . fst) asTypes)
 
