@@ -54,7 +54,6 @@ import System.IO
   , stdout
   )
 
-import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
 import Prettyprinter
   ( Pretty
   , (<+>)
@@ -154,7 +153,7 @@ doP =
      value DumpPretty <> showDefaultWith (drop 4 . show) <> ofHelp)
   where
     ofHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "output format" <>
       hardline <> list (map (pretty . drop 4 . show) ofchoices)
     ofchoices = [minBound .. maxBound] :: [DumpOutputFormat]
@@ -164,7 +163,7 @@ foP =
   FilteringOptions <$> argument str (metavar "EXPRESSION" <> filterTargetHelp)
   where
     filterTargetHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "packet filter expression" <+>
       softline <> pretty "see source for current syntax"
 
@@ -183,9 +182,9 @@ main = do
     (prefs showHelpOnError)
     (info
        (helper <*> versioner "hot" <*> cmd)
-       (headerDoc (Just (toAnsiWlPprint (banner "hot"))) <>
+       (headerDoc (Just (banner "hot")) <>
         progDesc "hOpenPGP OpenPGP-message Tool" <>
-        footerDoc (Just (toAnsiWlPprint (warranty "hot"))))) >>=
+        footerDoc (Just (warranty "hot")))) >>=
     dispatch
 
 cmd :: Parser Command
@@ -234,7 +233,7 @@ aoP =
     (long "armor-type" <> metavar "ARMORTYPE" <> armortypeHelp)
   where
     armortypeHelp =
-      helpDoc . Just . toAnsiWlPprint $
+      helpDoc . Just $
       pretty "ASCII armor type" <>
       softline <> list (map (pretty . fst) armorTypes)
 
